@@ -10,7 +10,7 @@ import adafruit_esp32spi.adafruit_esp32spi_socket as socket
 import neopixel
 
 
-import adafruit_minimqtt as MQTT
+import adafruit_minimqtt.adafruit_minimqtt as MQTT
 from adafruit_io.adafruit_io import IO_MQTT
 
 ### WiFi ###
